Method: Google::Longrunning::Operation#error

Defined in:
proto_docs/google/longrunning/operations.rb

#error::Google::Rpc::Status

Returns The error result of the operation in case of failure or cancellation.

Note: The following fields are mutually exclusive: error, response. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    The error result of the operation in case of failure or cancellation.

    Note: The following fields are mutually exclusive: error, response. If a field in that set is populated, all other fields in the set will automatically be cleared.



57
58
59
60
# File 'proto_docs/google/longrunning/operations.rb', line 57

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end