Method: Google::Longrunning::WaitOperationRequest#name

Defined in:
proto_docs/google/longrunning/operations.rb

#name::String

Returns The name of the operation resource to wait on.

Returns:

  • (::String)

    The name of the operation resource to wait on.



152
153
154
155
# File 'proto_docs/google/longrunning/operations.rb', line 152

class WaitOperationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end